        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,16,17,19,22,27,28,30,31,35,37,41,42,44,47,48';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 15 <br>5,9,11,12,13,14,20,21,23,24,34,40,43,46,50';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 13 <br>6,15,18,25,26,29,32,33,36,38,39,45,49';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,16,17,19,22,27,28,30,31,35,37,41,42,44,47,48';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 15 <br>5,9,11,12,13,14,20,21,23,24,34,40,43,46,50';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 13 <br>6,15,18,25,26,29,32,33,36,38,39,45,49';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,16,17,19,22,27,28,30,31,35,37,41,42,44,47,48';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 15 <br>5,9,11,12,13,14,20,21,23,24,34,40,43,46,50';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 13 <br>6,15,18,25,26,29,32,33,36,38,39,45,49';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,16,17,19,22,27,28,30,31,35,37,41,42,44,47,48';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 15 <br>5,9,11,12,13,14,20,21,23,24,34,40,43,46,50';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 13 <br>6,15,18,25,26,29,32,33,36,38,39,45,49';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,16,17,19,22,27,28,30,31,35,37,41,42,44,47,48';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 15 <br>5,9,11,12,13,14,20,21,23,24,34,40,43,46,50';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 13 <br>6,15,18,25,26,29,32,33,36,38,39,45,49';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,16,17,19,22,27,28,30,31,35,37,41,42,44,47,48';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 15 <br>5,9,11,12,13,14,20,21,23,24,34,40,43,46,50';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260615 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 13 <br>6,15,18,25,26,29,32,33,36,38,39,45,49';}
}
